# TensorFlow C++ Examples

This directory contains examples of the TensorFlow C++ API (and some redirects).
If that's not what you're looking for here are some links:

*   For TensorFlow python examples see
    [the tutorials on tensorflow.org](https://tensorflow.org/tutorials)
*   For community maintained keras examples goto
    [keras.io/examples](https://keras.io/examples/)
*   For TensorFlow Lite examples see
    [the tensorflow/examples repository](https://github.com/tensorflow/examples/tree/master/lite)
*   For the Udacity course notebooks, refer to
    [this directory](https://github.com/tensorflow/examples/tree/master/courses)

## About these examples

*   The C++ API is only easily buildable from within the TensorFlow `bazel`
    build. If you need a stand alone build
    [see the C API](https://www.tensorflow.org/install/lang_c).
*   This directory is not actively maintained.
